summaryrefslogtreecommitdiffstats
path: root/part/kxesettings.h
diff options
context:
space:
mode:
Diffstat (limited to 'part/kxesettings.h')
-rw-r--r--part/kxesettings.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/part/kxesettings.h b/part/kxesettings.h
index b1a98ea..f8713b6 100644
--- a/part/kxesettings.h
+++ b/part/kxesettings.h
@@ -20,7 +20,7 @@
#include <tqobject.h>
-class KConfig;
+class TDEConfig;
class TQFrame;
/**
@@ -45,26 +45,26 @@ class KXESettings : public TQObject
KXESettings( const TQString & strConfigGroup, TQObject * pParent = 0, const char * pszName = 0 );
/**
* Stores this settings to the given @ref KConfig object, by doing the
* following things:
*
* - set the config group by calling @ref setConfigGroup
* - write the data to the given @ref KConfig object by calling @ref write
* (which is implemented in the child class)
*/
- void store( KConfig * ) const;
+ void store( TDEConfig * ) const;
/**
* Restores the settings from the given @ref KConfig object, by doing
* following things:
*
* - set the config group by calling @ref setConfigGroup
* - read the data from the given @ref KConfig object by calling @ref read
* (which is implemented in the child class)
* - try to update the corresponding config.page by calling @ref updatePage
* (implemented in the child class)
* - emit the signal sigChanged
*/
- void restore( KConfig * );
+ void restore( TDEConfig * );
/**
* If the data in the corresponding configuration dialog page has been
* changed (@ref m_bPageChanged), this data gets applied by the
@@ -122,15 +122,15 @@ class KXESettings : public TQObject
protected:
/**
* Overide this function and write your settings to the given KConfig object.
* You mustn't change the config group.
*/
- virtual void write( KConfig * ) const = 0;
+ virtual void write( TDEConfig * ) const = 0;
/**
* Overide this function and read the settings from the given KConfig object.
* You mustn't change the config group.
*/
- virtual void read( const KConfig * ) = 0;
+ virtual void read( const TDEConfig * ) = 0;
/**
* Override this function to set this object's data to the data in the
* corresponding configuration dialog page, if a page has already been
@@ -145,10 +145,10 @@ class KXESettings : public TQObject
virtual void updatePage() const = 0;
/**
* Sets the config group of the given @ref KConfig object to
* this setting's config group (@ref m_strConfigGroup).
*/
- void setConfigGroup( KConfig * ) const;
+ void setConfigGroup( TDEConfig * ) const;
/**
* This flag is set to true if the data in the corresponding configuration
@@ -45,26 +45,26 @@ class KXESettings : public TQObject
KXESettings( const TQString & strConfigGroup, TQObject * pParent = 0, const char * pszName = 0 );
/**
- * Stores this settings to the given @ref KConfig object, by doing the
+ * Stores this settings to the given @ref TDEConfig object, by doing the
* following things:
*
@@ -45,26 +45,26 @@ class KXESettings : public TQObject
*
* - set the config group by calling @ref setConfigGroup
- * - write the data to the given @ref KConfig object by calling @ref write
+ * - write the data to the given @ref TDEConfig object by calling @ref write
* (which is implemented in the child class)
*/
@@ -45,26 +45,26 @@ class KXESettings : public TQObject
/**
- * Restores the settings from the given @ref KConfig object, by doing
+ * Restores the settings from the given @ref TDEConfig object, by doing
* following things:
*
@@ -45,26 +45,26 @@ class KXESettings : public TQObject
*
* - set the config group by calling @ref setConfigGroup
- * - read the data from the given @ref KConfig object by calling @ref read
+ * - read the data from the given @ref TDEConfig object by calling @ref read
* (which is implemented in the child class)
* - try to update the corresponding config.page by calling @ref updatePage
@@ -122,15 +122,15 @@ class KXESettings : public TQObject
protected:
/**
- * Overide this function and write your settings to the given KConfig object.
+ * Overide this function and write your settings to the given TDEConfig object.
* You mustn't change the config group.
*/
@@ -122,15 +122,15 @@ class KXESettings : public TQObject
/**
- * Overide this function and read the settings from the given KConfig object.
+ * Overide this function and read the settings from the given TDEConfig object.
* You mustn't change the config group.
*/
@@ -145,10 +145,10 @@ class KXESettings : public TQObject
virtual void updatePage() const = 0;
/**
- * Sets the config group of the given @ref KConfig object to
+ * Sets the config group of the given @ref TDEConfig object to
* this setting's config group (@ref m_strConfigGroup).
*/